/*
 * pthread.h
 *
 * Copyright 2008, Minoru Murashima. All rights reserved.
 * Distributed under the terms of the BSD License.
 */

#ifndef sys_pthread_h
#define sys_pthread_h

#include <sys/Thread.h>

#ifndef ASM_FILE

enum {
	PTHREAD_CREATE_JOINABLE = 1,		// default
	PTHREAD_CREATE_DETACHED,

	PTHREAD_EXPLICIT_SCHED = 1,			// default
	PTHREAD_INHERIT_SCHED,

	PTHREAD_SCOPE_PROCESS = 1,			// default
	PTHREAD_SCOPE_SYSTEM,
};

struct pthread_attr {
	int detachState;
	int schedPolicy;
	int schedParam;
	int inheritSched;
	int scope;
};

struct pthreadState {
	int taskState;
};

#endif // ASM_FILE

#endif // sys_pthread_h
